/**
 * @file filters.js
 * Block Admin filters
 */

BlockAdmin = {
  // Some classes and IDs, for reference
  p: {
    filters: "blockadmin-filters",
    masterFilter: "blockadmin-master-filter",
    allRows: ".blockadmin-block",
    someRows: ".blockadmin-block-",
    hideRow: 'blockadmin-hide'
  },

  // Initialize the filter change function
  initFilters: function() {
    var filter = jQuery("#" + BlockAdmin.p.masterFilter);
    filter.change(BlockAdmin.filterChange);

    // See if we've got a saved selection from previous visits
    var cookie = getCookie("blockadmin_selection");
    if (cookie !== undefined) {
      filter.val(cookie).change();
    }
  },

  filterChange: function(ev) {
    // Find out the selection value
    var sel = jQuery(this).find("option:selected").val();

    // Has the user selected all? If so, remove hide class
    if (sel == "") {
      jQuery(BlockAdmin.p.allRows).removeClass(BlockAdmin.p.hideRow);
    }
    // Otherwise, add the hide class to everything except the
    // selected module's rows
    else {
      jQuery(BlockAdmin.p.allRows).addClass(BlockAdmin.p.hideRow);
      jQuery(BlockAdmin.p.someRows + jQuery(this).find("option:selected").text())
        .removeClass(BlockAdmin.p.hideRow);

      // Save the selection for next time we're here
      setCookie("blockadmin_selection", sel, 10);
    }
  },

  go: function() {
    BlockAdmin.initFilters();
  }
};

// Cookie functions
function setCookie(c_name,value,exdays) {
  var exdate=new Date();
  exdate.setDate(exdate.getDate() + exdays);
  var c_value=escape(value) + ((exdays==null) ? "" : "; expires="+exdate.toUTCString());
  document.cookie=c_name + "=" + c_value;
}
function getCookie(c_name) {
  var i,x,y,ARRcookies=document.cookie.split(";");
  for (i=0;i<ARRcookies.length;i++) {
    x=ARRcookies[i].substr(0,ARRcookies[i].indexOf("="));
    y=ARRcookies[i].substr(ARRcookies[i].indexOf("=")+1);
    x=x.replace(/^\s+|\s+$/g,"");
    if (x==c_name) {
      return unescape(y);
    }
  }
}

// Assign as a Drupal behavior
Drupal.behaviors.blockAdmin = BlockAdmin.go;
